@@ -66,7 +66,7 @@ class BasicAdaptor:
         elif isinstance(db, bool):
             display = format_html("&check;" if db else "&cross;")
         else:
-            display = db
+            display = db.__str__()
         
         return display
 
@@ -80,6 +80,8 @@ class BasicAdaptor:
                     reversion.set_user(self._user)
         else:
             self._model.save()
+            
+        self._model.refresh_from_db() # reload from DB
 
     def has_edit_perm(self, user):
         return __check_edit_access__(user, self._model, self._field)
